HttpJsonRpcClient

Struct HttpJsonRpcClient 

pub struct HttpJsonRpcClient { /* private fields */ }
A builder to create a http jsonrpc client.

Implementations

Source

impl HttpJsonRpcClient

pub fn new<T>(uri: T) -> Self
where Uri: TryFrom<T>, <Uri as TryFrom<T>>::Error: Into<HttpError>,

Create new http rpc client builder with server uri.

pub fn header<K, V>(self, key: K, value: V) -> Self

Appends a http header to the http JsonRpcClient builder.

pub fn extension<T>(self, extension: T) -> Self
where T: Clone + Any + Send + Sync + 'static,

Add an extension to the http JsonRpcClient builder.

pub fn redirect<R: ToSocketAddrs>(self, raddrs: R) -> Self

Rewrite http request’s host:port fields and send request to the specified raddrs.

pub fn with_server_name(self, server_name: &str) -> Self

Set remote server’s server name, this option will rewrite request’s host field.

pub fn with_ca_file<P: AsRef<Path>>(self, ca_file: P) -> Self

Set the server verification ca file, this is useful for self signed server.

pub fn timeout(self, duration: Duration) -> Self

Set the timeout duration of the jsonrpc call via http request.

pub fn set_use_server_name_indication(self, value: bool) -> Self

Configures the use of Server Name Indication (SNI) when connecting. Defaults to true.

pub fn create(self) -> Result<JsonRpcClient>

Consume builder and create a new JsonRpcClient instance.